@@ -95,6 +95,10 @@ SYMBOLS_PER_EXCHANGE.append(
                 ("ONT", "USDT"),
                 ("HBAR", "USDT"),
                 ("HBAR", "BTC"),
+                ("SNX", "USDT"),
+                ("SNX", "BTC"),
+                ("RLC", "USDT"),
+                ("RLC", "BTC"),
             ],
         }
     }
@@ -176,7 +180,16 @@ SYMBOLS_PER_EXCHANGE.append({IDEX: {"pairs": []}})
 
 # OKCoin
 SYMBOLS_PER_EXCHANGE.append(
-    {OKCOIN: {"pairs": [("BTC", "USD"), ("ETH", "USD"), ("LTC", "USD"),]}}
+    {
+        OKCOIN: {
+            "pairs": [
+                ("BTC", "USD"),
+                ("ETH", "USD"),
+                ("LTC", "USD"),
+                ("USDT", "USD"),
+            ]
+        }
+    }
 )
 
 # LIQUID
@@ -191,14 +204,7 @@ SYMBOLS_PER_EXCHANGE.append({COINBENE: {"pairs": []}})
 SYMBOLS_PER_EXCHANGE.append({HOTBIT: {"pairs": [], "single_request": True,}})
 
 # Bilaxy
-SYMBOLS_PER_EXCHANGE.append(
-    {
-        BILAXY: {
-            "pairs": [("BTC", "USDT"), ("ETH", "USDT"),],
-            "single_request": True,
-        }
-    }
-)
+SYMBOLS_PER_EXCHANGE.append({BILAXY: {"pairs": [], "single_request": True,}})
 
 # Uphold
 SYMBOLS_PER_EXCHANGE.append(
@@ -221,7 +227,7 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
     "BTC": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "EUR"]},
     },
     "ETH": {
         "pair": "USDT",
@@ -236,33 +242,29 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
     "XRP": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "LTC": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "BNB": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "XLM": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "USDC": {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
     },
-    "USDT": {
-        "pair": "DAI",
-        "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["DAI"]},
-    },
+    "USDT": {"pair": "USD", "name": OKCOIN,},
     "DAI": {"pair": "USD", "name": COINBASE_PRO,},
     "LTO": {
         "pair": "USDT",
@@ -275,15 +277,15 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "EWT": {"pair": "USDT", "name": KUCOIN,},
-    "ADA": {
+    "RLC": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
-    "XTZ": {
+    "SNX": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "KNC": {
         "pair": "USDT",
@@ -310,11 +312,21 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
+    "ADA": {
+        "pair": "USDT",
+        "name": BINANCE,
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+    },
+    "XTZ": {
+        "pair": "USDT",
+        "name": BINANCE,
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+    },
     "NU": {"pair": "USD", "name": COINBASE_PRO,},
     "XMR": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "VET": {
         "pair": "USDT",
