@@ -27,17 +27,29 @@ URL = f"https://etherscan.io/token/{TETHER_CONTRACT_ADDRESS}"
 def _get_tether_num_holders():
     scraper = cfscrape.create_scraper()
     soup = BeautifulSoup(scraper.get(URL).content, "html.parser")
+    selector = soup.find(id="ContentPlaceHolder1_tr_tokenHolders").find_all(
+        "div"
+    )[-1]
     try:
         return int(
-            soup.find(id="ContentPlaceHolder1_tr_tokenHolders")
-            .find_all("div")[-1]
-            .string.replace(".", "")
+            selector.string.replace(".", "")
             .replace(",", "")
             .replace("addresses", "")
             .strip()
         )
     except AttributeError:
-        return
+        pass
+    try:
+        # @note: HTML structure changed a bit recently
+        return int(
+            selector.text.replace(".", "")
+            .replace(",", "")
+            .replace("addresses", "")
+            .strip()
+            .split()[0]
+        )
+    except AttributeError:
+        pass
 
 
 @task(bind=True)
